Python: package boopak

boopak | index boopak/__init__.py

`# Boodler: a programmable soundscape tool
# Copyright 2001-9 by Andrew Plotkin <erkyrath@eblong.com>
# <http://boodler.org/>
# This program is distributed under the LGPL.
# See the LGPL document, or the above URL, for details.`

Package Contents
`` |  |
argdef collect emptymodule fetch | package pinfo pload sparse | test_argdef test_pinfo test_pload test_sparse | test_version testing version

Data
`` |  | __all__ = ['collect', 'fetch', 'package', 'pinfo', 'pload', 'version']